// Example of basic graphics in Java. This class works with DrawingDemo.java

import java.awt.*;       // Graphics, Graphics2D, Color, Polygon
import java.awt.geom.*;  // Rectangle2D, Ellipse2D, Line2D, Arc2D
import javax.swing.*;    // JPanel

public class MyPicture extends JPanel { // MyPicture is a kind of JPanel
    
    public void paintComponent(Graphics g) {
        // paintComponent must start with these two lines
        super.paintComponent(g);
        Graphics2D pen = (Graphics2D) g;

        // sets the panel background color
        this.setBackground(Color.PINK);

        // Ellipse2D.Double constructor parameters:
        // - x1, y1 coordinate of upper-left corner of framing rectangle
        // - width, height of framing rectangle

        Ellipse2D.Double ellipse = new Ellipse2D.Double(30, 40, 400, 200);
        pen.setColor(Color.BLUE);
        pen.draw(ellipse);

        // Rectangle2D.Double constructor parameters:
        // - x1, y1 coordinate of upper left corner
        // - width, height of rectangle

        Rectangle2D.Double rect = new Rectangle2D.Double(350, 100, 90, 50);
        pen.setColor(Color.RED);
        pen.fill(rect);

        // Line2D.Double constructor parameters:
        // - x1, y1 coordinate of starting point
        // - x2, y2 coordinate of ending point

        Line2D.Double line = new Line2D.Double(100, 300, 300, 200);
        pen.setColor(Color.BLACK);
        pen.draw(line);

        // Arc2D.Double constructor parameters:
        // - x1, y1 coordinate of upper left corner of framing rectangle
        // - width, height of framing rectangle
        // - starting angle of arc in degrees (0 degrees = "east")
        // - angular sweep of arc in degrees (positive = counterclockwise)
        // - shape: Arc2D.OPEN, Arc2D.CHORD, or Arc2D.PIE

        Arc2D.Double pieSlice = new Arc2D.Double(100, 300, 350, 200, 30, 60, Arc2D.PIE);
        pen.setColor(Color.GREEN);
        pen.fill(pieSlice);

        Arc2D.Double fullOutline = new Arc2D.Double(100, 300, 350, 200, 0, 360, Arc2D.OPEN);
        pen.draw(fullOutline);

        Rectangle2D.Double box = new Rectangle2D.Double(100, 300, 350, 200);
        pen.setColor(Color.MAGENTA);
        pen.draw(box);

        // create an empty polygon and add vertex points one by one
        Polygon polygon = new Polygon();
        polygon.addPoint(450, 220);
        polygon.addPoint(475, 140);
        polygon.addPoint(550, 150);
        polygon.addPoint(560, 200);
        polygon.addPoint(525, 260);
        pen.setColor(Color.YELLOW);  // draw yellow interior
        pen.fill(polygon);
        pen.setColor(Color.BLUE);    // draw blue border
        pen.draw(polygon);
    }
}
